|
Boost-Commit : |
From: john_at_[hidden]
Date: 2007-08-29 13:15:55
Author: johnmaddock
Date: 2007-08-29 13:15:54 EDT (Wed, 29 Aug 2007)
New Revision: 39055
URL: http://svn.boost.org/trac/boost/changeset/39055
Log:
Fix mingw regression.
Text files modified:
sandbox/math_toolkit/libs/math/test/test_triangular.cpp | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)
Modified: sandbox/math_toolkit/libs/math/test/test_triangular.cpp
==============================================================================
--- sandbox/math_toolkit/libs/math/test/test_triangular.cpp (original)
+++ sandbox/math_toolkit/libs/math/test/test_triangular.cpp 2007-08-29 13:15:54 EDT (Wed, 29 Aug 2007)
@@ -425,7 +425,7 @@
tolerance);
tolerance = (std::max)(
boost::math::tools::epsilon<RealType>(),
- static_cast<RealType>(boost::math::tools::epsilon<double>())) * 5; // 5 eps as a fraction.
+ static_cast<RealType>(boost::math::tools::epsilon<double>())) * 10; // 10 eps as a fraction.
cout << "Tolerance (as fraction) for type " << typeid(RealType).name() << " is " << tolerance << "." << endl;
triangular_distribution<RealType> tridef; // (-1, 0, 1) // default
RealType x = static_cast<RealType>(0.5);
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk